PoolerPgbouncer

Struct PoolerPgbouncer 

pub struct PoolerPgbouncer {
    pub auth_query: Option<String>,
    pub auth_query_secret: Option<PoolerPgbouncerAuthQuerySecret>,
    pub client_ca_secret: Option<PoolerPgbouncerClientCaSecret>,
    pub client_tls_secret: Option<PoolerPgbouncerClientTlsSecret>,
    pub parameters: Option<BTreeMap<String, String>>,
    pub paused: Option<bool>,
    pub pg_hba: Option<Vec<String>>,
    pub pool_mode: Option<PoolerPgbouncerPoolMode>,
    pub server_ca_secret: Option<PoolerPgbouncerServerCaSecret>,
    pub server_tls_secret: Option<PoolerPgbouncerServerTlsSecret>,
}
The PgBouncer configuration

Fields

auth_query: Option<String>

The query that will be used to download the hash of the password of a certain user. Default: “SELECT usename, passwd FROM public.user_search($1)”. In case it is specified, also an AuthQuerySecret has to be specified and no automatic CNPG Cluster integration will be triggered.

auth_query_secret: Option<PoolerPgbouncerAuthQuerySecret>

The credentials of the user that need to be used for the authentication query. In case it is specified, also an AuthQuery (e.g. “SELECT usename, passwd FROM pg_catalog.pg_shadow WHERE usename=$1”) has to be specified and no automatic CNPG Cluster integration will be triggered.

Deprecated.

client_ca_secret: Option<PoolerPgbouncerClientCaSecret>

ClientCASecret provides PgBouncer’s client_tls_ca_file, the root CA for validating client certificates

client_tls_secret: Option<PoolerPgbouncerClientTlsSecret>

ClientTLSSecret provides PgBouncer’s client_tls_key_file (private key) and client_tls_cert_file (certificate) used to accept client connections

parameters: Option<BTreeMap<String, String>>

Additional parameters to be passed to PgBouncer - please check the CNPG documentation for a list of options you can configure

paused: Option<bool>

When set to true, PgBouncer will disconnect from the PostgreSQL server, first waiting for all queries to complete, and pause all new client connections until this value is set to false (default). Internally, the operator calls PgBouncer’s PAUSE and RESUME commands.

pg_hba: Option<Vec<String>>

PostgreSQL Host Based Authentication rules (lines to be appended to the pg_hba.conf file)

pool_mode: Option<PoolerPgbouncerPoolMode>

The pool mode. Default: session.

server_ca_secret: Option<PoolerPgbouncerServerCaSecret>

ServerCASecret provides PgBouncer’s server_tls_ca_file, the root CA for validating PostgreSQL certificates

server_tls_secret: Option<PoolerPgbouncerServerTlsSecret>

ServerTLSSecret, when pointing to a TLS secret, provides pgbouncer’s server_tls_key_file and server_tls_cert_file, used when authenticating against PostgreSQL.